@@ -7,7 +7,7 @@ use POSIX 'WNOHANG';
 
 has watch => sub { [qw(lib templates)] };
 
-# "All in all, this is one day Mittens the kitten won’t soon forget.
+# "All in all, this is one day Mittens the kitten won't soon forget.
 #  Kittens give Morbo gas.
 #  In lighter news, the city of New New York is doomed.
 #  Blame rests with known human Professor Hubert Farnsworth and his tiny,
@@ -39,7 +39,7 @@ sub run {
   exit 0;
 }
 
-# "And so with two weeks left in the campaign, the question on everyone’s
+# "And so with two weeks left in the campaign, the question on everyone's
 #  mind is, who will be the president of Earth?
 #  Jack Johnson or bitter rival John Jackson.
 #  Two terrific candidates, Morbo?
@@ -123,8 +123,7 @@ Mojo::Server::Morbo - DOOOOOOOOOOOOOOOOOOM!
 
 L<Mojo::Server::Morbo> is a full featured self-restart capable non-blocking
 I/O HTTP 1.1 and WebSocket server built around the very well tested and
-reliable L<Mojo::Server::Daemon> with C<IPv6>, C<TLS>, C<Bonjour> and C<libev>
-support.
+reliable L<Mojo::Server::Daemon> with C<IPv6>, C<TLS> and C<libev> support.
 
 To start applications with it you can use the L<morbo> script.
 
@@ -133,8 +132,10 @@ To start applications with it you can use the L<morbo> script.
 
 Optional modules L<EV>, L<IO::Socket::IP>, L<IO::Socket::SSL> and
 L<Net::Rendezvous::Publish> are supported transparently and used if installed.
-Individual features can also be disabled with the C<MOJO_NO_BONJOUR>,
-C<MOJO_NO_IPV6> and C<MOJO_NO_TLS> environment variables.
+Individual features can also be disabled with the C<MOJO_NO_IPV6> and
+C<MOJO_NO_TLS> environment variables.
+
+See L<Mojolicious::Guides::Cookbook> for more.
 
 =head1 ATTRIBUTES
 
