@@ -24,12 +24,6 @@ sub run {
   my $tls
     = Mojo::IOLoop::Server::TLS ? $IO::Socket::SSL::VERSION : 'not installed';
 
-  # Bonjour
-  my $bonjour
-    = Mojo::Server::Daemon::BONJOUR
-    ? $Net::Rendezvous::Publish::VERSION
-    : 'not installed';
-
   print <<"EOF";
 CORE
   Perl        ($^V, $^O)
@@ -39,7 +33,6 @@ OPTIONAL
   EV                       ($ev)
   IO::Socket::IP           ($ipv6)
   IO::Socket::SSL          ($tls)
-  Net::Rendezvous::Publish ($bonjour)
 
 EOF
 
