@@ -113,13 +113,8 @@ sub run {
 
 sub start {
   my $self = shift;
-
-  # Executable
-  $ENV{MOJO_EXE} ||= (caller)[1] if $ENV{MOJO_APP};
-
-  # Run
   my @args = @_ ? @_ : @ARGV;
-  ref $self ? $self->run(@args) : $self->new->run(@args);
+  return ref $self ? $self->run(@args) : $self->new->run(@args);
 }
 
 sub start_app {
