@@ -38,18 +38,13 @@ sub register {
   # Config file
   my $file = $conf->{file} || $ENV{MOJO_CONFIG};
   unless ($file) {
+
+    # Class or executable
     $file = $ENV{MOJO_APP};
+    $file = $file && !ref $file ? decamelize($file) : basename($ENV{MOJO_EXE});
 
-    # Class
-    if ($file && !ref $file) { $file = decamelize $file }
-
-    # File
-    else { $file = basename($ENV{MOJO_EXE} || $0) }
-
-    # Remove .pl and .t extentions
+    # Replace ".pl" and ".t" with default extension
     $file =~ s/\.(?:pl|t)$//i;
-
-    # Default extension
     $file .= '.' . ($conf->{ext} || 'conf');
   }
 
@@ -111,11 +106,16 @@ Mojolicious::Plugin::Config - Perl-ish configuration plugin
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::Config> is a Perl-ish configuration plugin. The
-application object can be accessed via C<$app> or the C<app> function. You can
-extend the normal configuration file C<myapp.conf> with C<mode> specific ones
-like C<myapp.$mode.conf>. The code of this plugin is a good example for
-learning to build new plugins.
+L<Mojolicious::Plugin::Config> is a Perl-ish configuration plugin.
+
+The application object can be accessed via C<$app> or the C<app> function. You
+can extend the normal configuration file C<myapp.conf> with C<mode> specific
+ones like C<myapp.$mode.conf>. A default configuration filename will be
+generated by decamelizing the application class with
+L<Mojo::Util/"decamelize"> or from the application filename.
+
+The code of this plugin is a good example for learning to build new plugins,
+you're welcome to fork it.
 
 =head1 OPTIONS
 
@@ -133,7 +133,7 @@ Default configuration, making configuration files optional.
   # Mojolicious::Lite
   plugin Config => {ext => 'stuff'};
 
-File extension for generated configuration file names, defaults to C<conf>.
+File extension for generated configuration filenames, defaults to C<conf>.
 
 =head2 C<file>
 
